@@ -20,9 +20,9 @@ MONGO_QUERY_BLACKLIST = ['$where']
 RENDERERS = ['eve.render.JSONRenderer']  # removed eve.render.XMLRenderer
 
 DATE_FORMAT = '%Y-%m-%dT%H:%M:%S'
-PAGINATION_LIMIT = 3000
-PAGINATION_DEFAULT = 1000
-OPTIMIZE_PAGINATION_FOR_SPEED = True
+PAGINATION_LIMIT = SETTINGS.get('ES_PAGINATION_LIMIT')
+PAGINATION_DEFAULT = SETTINGS.get('ES_PAGINATION_DEFAULT')
+OPTIMIZE_PAGINATION_FOR_SPEED = False
 
 
 # http://python-eve.org/features.html#operations-log
@@ -50,7 +50,7 @@ X_HEADERS = [
 RETURN_MEDIA_AS_BASE64_STRING = False
 RETURN_MEDIA_AS_URL = True
 
-if 'MEDIA_BASE_URL' in SETTINGS.keys():
+if 'ES_MEDIA_BASE_URL' in SETTINGS.keys():
     MEDIA_BASE_URL = SETTINGS.get('ES_MEDIA_BASE_URL')
 EXTENDED_MEDIA_INFO = ['content_type', 'name', 'length']
 
